from django.conf import settings
from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, SEOModel
from jmb.i18n.models import TranslationModel, I18NModel
from jmb.core.db.fields import HTMLField, HTMLFieldTinyMCE

class Office (DateModel, UserModel, StatusModel):
    """
    Store Office
    """
    code = models.CharField (
        unique = True,
        max_length = 15,
        verbose_name = _("code")
    )
    name = models.CharField (
        unique = True,
        max_length = 50,
        verbose_name = _("office")
    )
    description = models.TextField (
        blank = True, null = True,
        max_length = 255,
        verbose_name = _("description")
    )
    phone = models.CharField (
        max_length = 20,
        verbose_name = _("phone"),
    )
    fax = models.CharField (
        max_length = 20,
        verbose_name = _("fax"),
    )
    email = models.EmailField (
        max_length = 100,
        blank = True, null = True,
        verbose_name = _("email"),
    )

    class Meta:
        verbose_name = _("office")
        verbose_name_plural = _("offices")

    def __unicode__(self):
        return u"%s" % self.name
